@@ -5,7 +5,7 @@
 #  /_/\_\|_|  \_/\_/  |_||_| |_| \__, ||___/ _____  \__,_| \__||_||_||___/
 #                                |___/      |_____|
 
-__version__ = "25.1.2"
+__version__ = "25.1.3"
 
 
 from pathlib import Path
@@ -15,6 +15,8 @@ import math
 import base64
 import requests
 import json
+import datetime
+import functools
 
 Pythonista = sys.platform == "ios"
 
@@ -134,12 +136,18 @@ def list_dropbox(path="", recursive=False, show_files=True, show_folders=False):
     headers = {"Authorization": f"Bearer {_token}", "Content-Type": "application/json"}
     payload = {"path": str(path), "recursive": recursive, "include_deleted": False}
     response = requests.post("https://api.dropboxapi.com/2/files/list_folder", headers=headers, json=payload, timeout=30)
-    response.raise_for_status()
+    try:
+        response.raise_for_status()
+    except requests.exceptions.HTTPError as e:
+        raise OSError(f"error listing dropbox. Original message is {e}") from None
     data = response.json()
     entries = data["entries"]
     while data.get("has_more"):
         response = requests.post(f"{API_RPC}/files/list_folder/continue", headers=headers, json={"cursor": data["cursor"]}, timeout=30)
-        response.raise_for_status()
+        try:
+            response.raise_for_status()
+        except requests.exceptions.HTTPError as e:
+            raise OSError(f"error listing dropbox. Original message is {e}") from None
         data = response.json()
         entries.extend(data["entries"])
 
@@ -165,6 +173,10 @@ def read_dropbox(dropbox_path):
     -------
     contents of the dropbox file : bytes
 
+    Note
+    ----
+    If the file could not be read, an OSError will be raised.
+
     Note
     ----
     If REFRESH_TOKEN, APP_KEY and APP_SECRET environment variables are specified,
@@ -177,7 +189,7 @@ def read_dropbox(dropbox_path):
         try:
             response.raise_for_status()
         except requests.exceptions.HTTPError as e:
-            raise FileNotFoundError(f"file {str(dropbox_path)} not found. Original message is {e}") from None
+            raise OSError(f"file {str(dropbox_path)} not found. Original message is {e}") from None
         chunks = []
         for chunk in response.iter_content(chunk_size=1024):
             if chunk:
@@ -197,6 +209,10 @@ def write_dropbox(dropbox_path, contents):
     contents : bytes
         contents to be written
 
+    Note
+    ----
+    If the file could not be written, an OSError will be raised.
+        
     Note
     ----
     If REFRESH_TOKEN, APP_KEY and APP_SECRET environment variables are specified,
@@ -211,6 +227,10 @@ def write_dropbox(dropbox_path, contents):
         "Content-Type": "application/octet-stream",
     }
     response = requests.post("https://content.dropboxapi.com/2/files/upload", headers=headers, data=contents)
+    try:
+        response.raise_for_status()
+    except requests.exceptions.HTTPError as e:
+        raise OSError(f"file {str(dropbox_path)} could not be written. Original message is {e}") from None
     return response
 
 
@@ -223,6 +243,10 @@ def delete_from_dropbox(dropbox_path):
     dropbox_path : str or Pathlib.Path
         path to delete
 
+    Note
+    ----
+    If the file could not be deleted, an OSError will be raised.
+
     Note
     ----
     If REFRESH_TOKEN, APP_KEY and APP_SECRET environment variables are specified,
@@ -235,9 +259,11 @@ def delete_from_dropbox(dropbox_path):
     data = {"path": str(dropbox_path)}  # Path in Dropbox, starting with /
 
     response = requests.post("https://api.dropboxapi.com/2/files/delete_v2", headers=headers, data=json.dumps(data))
-    if response.status_code == 200:
-        return response
-    raise FileNotFoundError(f"dropbox file {dropbox_path} not found")
+    try:
+        response.raise_for_status()
+    except requests.exceptions.HTTPError as e:
+        raise OSError(f"file {str(dropbox_path)} could not be deleted. Original message is {e}") from None
+    return response
 
 
 def list_local(path, recursive=False, show_files=True, show_folders=False):
@@ -1037,6 +1063,29 @@ def trigger_macro(sheet):
     sheet["A1"].value = "=NOW()"
 
 
+def timer(func):
+    """
+    this decorator should be placed after the @xw.script decorator
+
+    it will show the name, entry time, exit time and the duration, like
+    Done MyScript  11:51:13.24 - 11:51:20.28 (7.04s)
+
+    """
+
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        now0 = datetime.datetime.now()
+        result = func(*args, **kwargs)
+        now1 = datetime.datetime.now()
+        t0 = now0.second + now0.microsecond / 1_000_000
+        t1 = now1.second + now1.microsecond / 1_000_000
+        print(
+            f"Done {func.__name__}  {now0:%H:%M:%S.}{int(now0.microsecond / 10000):02d} - {now1:%H:%M:%S.}{int(now1.microsecond / 10000):02d} ({t1 - t0:.2f}s)"
+        )
+        return result
+
+    return wrapper
+
+
 if __name__ == "__main__":
     ...
-
